@@ -1,3 +1,9 @@
+"""WrightTools init."""
+
+
+# --- import --------------------------------------------------------------------------------------
+
+
 import sys as _sys
 import os as _os
 
@@ -7,17 +13,33 @@ import matplotlib as _matplotlib
 # --- temp directory ------------------------------------------------------------------------------
 
 
-_temp_dir = _os.path.join(_os.path.dirname(__file__), 'temp')
+_here = _os.path.abspath(_os.path.dirname(__file__))
+
+_temp_dir = _os.path.join(_here, 'temp')
 if not _os.path.isdir(_temp_dir):
     _os.mkdir(_temp_dir)
 
 
+# --- import --------------------------------------------------------------------------------------
+
+
+from . import artists           # noqa: F401
+from . import calibration       # noqa: F401
+from . import data              # noqa: F401
+from . import diagrams          # noqa: F401
+from . import fit               # noqa: F401
+from . import google_drive      # noqa: F401
+from . import kit               # noqa: F401
+from . import tuning            # noqa: F401
+from . import units             # noqa: F401
+
+
 # --- version -------------------------------------------------------------------------------------
 
 
-# MAJOR.MINOR.PATCH (semantic versioning)
-# major version changes may break backwards compatibility
-__version__ = '2.13.4'
+# read from VERSION file
+with open(_os.path.join(_os.path.dirname(_here), 'VERSION')) as _version_file:
+    __version__ = _version_file.read().strip()
 
 # add git branch, if appropriate
 _directory = _os.path.dirname(_os.path.dirname(__file__))
@@ -31,20 +53,6 @@ else:
     __branch__ = None
 
 
-# --- import --------------------------------------------------------------------------------------
-
-
-from . import artists
-from . import calibration
-from . import data
-from . import diagrams
-from . import fit
-from . import google_drive
-from . import kit
-from . import tuning
-from . import units
-
-
 # --- rcparams ------------------------------------------------------------------------------------
 
 if int(_sys.version.split('.')[0]) > 2 and int(_matplotlib.__version__.split('.')[0]) > 1:
