@@ -1,5 +1,13 @@
 """
-a collection of small, general purpose objects and methods
+A collection of small, general purpose objects and methods.
+
+.. _RFC3339: https://www.ietf.org/rfc/rfc3339.txt
+.. _RFC5322: https://tools.ietf.org/html/rfc5322#section-3.3
+.. _HDF5: https://www.hdfgroup.org/HDF5/doc/H5.intro.html
+.. _intersperse: http://stackoverflow.com/a/5921708
+.. _flatten: http://stackoverflow.com/questions/2158395
+.. _suppress:
+    http://stackoverflow.com/questions/11130156/suppress-stdout-stderr-print-from-python-functions
 """
 
 
@@ -16,10 +24,10 @@ import copy
 import time
 import pytz
 import h5py
+import string
 import warnings
 import dateutil
 import datetime
-import itertools
 import linecache
 import collections
 from time import clock
@@ -41,7 +49,8 @@ from . import units as wt_units
 
 
 if sys.version[0] == '2':
-    string_type = basestring  # recognize unicode and string types
+    # recognize unicode and string types
+    string_type = basestring  # noqa: F821
 else:
     string_type = str  # newer versions of python don't have unicode type
 
@@ -51,9 +60,11 @@ else:
 
 def get_timestamp(style='RFC3339', at=None, hms=True, frac=False,
                   timezone='here', filename_compatible=False):
-    """ Get the current time as a string.
+    """Get the current time as a string.
 
-    LEGACY - please use TimeStamp objects.
+    .. note: Deprecated
+             `get_timestamp` is no longer supported
+             Use `Timestamp` objects instead
 
     Parameters
     ----------
@@ -147,9 +158,10 @@ def get_timestamp(style='RFC3339', at=None, hms=True, frac=False,
 
 
 class TimeStamp:
+    """Class for representing a moment in time."""
 
     def __init__(self, at=None, timezone='local'):
-        """ Class for representing a moment in time.
+        """Create a ``TimeStamp`` object.
 
         Parameters
         ----------
@@ -173,11 +185,13 @@ class TimeStamp:
         legacy : string
             Legacy WrightTools timestamp representation.
         RFC3339 : string
-            `RFC3339 <https://www.ietf.org/rfc/rfc3339.txt>`_ representation (recommended for most applications).
+            `RFC3339`_ representation (recommended for most applications).
         RFC5322 : string
-            `RFC5322 <https://tools.ietf.org/html/rfc5322#section-3.3>`_ representation.
+            `RFC5322`_ representation.
         path : string
             Representation of the timestamp meant for inclusion in filepaths.
+
+
         """
         # get timezone
         if timezone == 'local':
@@ -200,21 +214,28 @@ class TimeStamp:
             self.datetime = datetime.datetime.fromtimestamp(at, self.tz)
 
     def __repr__(self):
-        return self.RFC3339
+        """Unambiguous representation."""
+        return str(self.unix)
 
     def __str__(self):
-        return str(self.unix)
+        """Readable representation."""
+        return self.RFC3339
 
     @property
     def date(self):
+        """year-month-day."""
         return self.datetime.strftime('%Y-%m-%d')
 
     @property
     def hms(self):
+        """Get time formated.
+
+        ``HH:MM:SS``"""
         return self.datetime.strftime('%H:%M:%S')
 
     @property
     def human(self):
+        """Human-readable timestamp."""
         # get timezone offset
         delta_sec = time.timezone
         m, s = divmod(delta_sec, 60)
@@ -226,10 +247,12 @@ class TimeStamp:
 
     @property
     def legacy(self):
+        """Legacy timestamp format."""
         return self.datetime.strftime('%Y.%m.%d %H_%M_%S')
 
     @property
     def RFC3339(self):
+        """RFC3339_."""
         # get timezone offset
         delta_sec = time.timezone
         m, s = divmod(delta_sec, 60)
@@ -253,10 +276,12 @@ class TimeStamp:
 
     @property
     def RFC5322(self):
+        """RFC5322_."""
         return self.datetime.astimezone(tz=pytz.utc).strftime('%a, %d %b %Y %H:%M:%S GMT')
 
     @property
     def path(self):
+        """Timestamp for placing into filepaths."""
         out = self.datetime.strftime('%Y-%m-%d')
         out += ' '
         ssm = (
@@ -271,6 +296,17 @@ class TimeStamp:
 
 
 def timestamp_from_RFC3339(RFC3339):
+    """Generate a Timestamp object from a RFC3339_ formatted string.
+
+    Parameters
+    ----------
+    RFC3339 : string
+        RFC3339 formatted string.
+
+    Returns
+    -------
+    WrightTools.kit.TimeStamp
+    """
     dt = dateutil.parser.parse(RFC3339)
     timezone = dt.tzinfo._offset.total_seconds()
     unix = (dt - datetime.datetime(1970, 1, 1, tzinfo=pytz.utc)
@@ -283,7 +319,7 @@ def timestamp_from_RFC3339(RFC3339):
 
 
 def filename_parse(fstr):
-    """ parses a filepath string into it's path, name, and suffix """
+    """Parse a filepath string into it's path, name, and suffix."""
     folder, filename = os.path.split(fstr)
 
     split = filename.split('.', 1)
@@ -296,9 +332,9 @@ def filename_parse(fstr):
 
 
 def file_len(fname):
-    """ Cheaply get the number of lines in a file.'
+    """Cheaply get the number of lines in a file.
 
-    File is not entirely loaded into memory.
+    File is not entirely loaded into memory at once.
     """
     # adapted from http://stackoverflow.com/questions/845058
     with open(fname) as f:
@@ -307,45 +343,15 @@ def file_len(fname):
     return i + 1
 
 
-def find_name(fname, suffix):
-    """
-    save the file using fname, and tacking on a number if fname already exists
-    iterates until a unique name is found
-    returns False if the loop malfunctions
-    """
-    good_name = False
-    # find a name that isn't used by enumerating
-    i = 1
-    while not good_name:
-        try:
-            with open(fname + '.' + suffix):
-                # file does exist
-                # see if a number has already been guessed
-                if fname.endswith(' ({0})'.format(i - 1)):
-                    # cut the old off before putting the new in
-                    fname = fname[:-len(' ({0})'.format(i - 1))]
-                fname += ' ({0})'.format(i)
-                i = i + 1
-                # prevent infinite loop if the code isn't perfect
-                if i > 100:
-                    print('didn\'t find a good name; index used up to 100!')
-                    fname = False
-                    good_name = True
-        except IOError:
-            # file doesn't exist and is safe to write to this path
-            good_name = True
-    return
-
-
 class FileSlicer:
+    """Access groups of lines from a file quickly, without loading the entire file into memory.
+
+    Mostly a convinient wrapper around the standard library linecache
+    module.
+    """
 
     def __init__(self, path, skip_headers=True, header_charachter='#'):
-        """ Access groups of lines from a file quickly, without loading the entire file into memory.
-
-        Lines are accesed from Useful especially in cases where
-
-        Mostly a convinient wrapper around the standard library 'linecache'
-        module.
+        """Create a ``FileSlicer`` object.
 
         Parameters
         ----------
@@ -366,11 +372,11 @@ class FileSlicer:
                     self.n += 1
 
     def close(self):
-        """ Clear the cache, attempting to free as much memory as possible.  """
+        """Clear the cache, attempting to free as much memory as possible."""
         linecache.clearcache()
 
     def get(self, line_count):
-        """ Get the next group of lines from the file.
+        """Get the next group of lines from the file.
 
         Parameters
         ----------
@@ -396,7 +402,8 @@ class FileSlicer:
         return out
 
     def skip(self, line_count):
-        """ Skip the next group of lines from the file.
+        """Skip the next group of lines from the file.
+
         Parameters
         ----------
         line_count : int
@@ -409,13 +416,19 @@ class FileSlicer:
         self.n += line_count
 
 
-def get_box_path():
-    """ LEGACY METHOD. Use ``get_path_matching(name)`` instead.  """
-    box_path = get_path_matching('Box Sync')
-    return os.path.join(box_path, 'Wright Shared')
-
-
 def get_path_matching(name):
+    """Get path matching a name.
+
+    Parameters
+    ----------
+    name : string
+        Name to search for.
+
+    Returns
+    -------
+    string
+        Full filepath.
+    """
     # first try looking in the user folder
     p = os.path.join(os.path.expanduser('~'), name)
     # then try expanding upwards from cwd
@@ -431,11 +444,14 @@ def get_path_matching(name):
 
 
 def glob_handler(extension, folder=None, identifier=None):
-    """
-    returns a list of all files matching specified inputs
-    if no folder is specified, looks in chdir
-    """
+    """Return a list of all files matching specified inputs.
 
+    Parameters
+    ----------
+    extension: string
+    folder: string
+    identifier: string
+    """
     import glob
 
     filepaths = []
@@ -461,9 +477,16 @@ def glob_handler(extension, folder=None, identifier=None):
 
 
 class INI():
+    """Handle communication with an INI file."""
 
     def __init__(self, filepath):
-        """ Handle communication with an INI file.  """
+        """Create an INI handler object.
+
+        Parameters
+        ----------
+        filepath : string
+            Filepath.
+        """
         self.filepath = filepath
         if sys.version[0] == '3':
             self.config = configparser.ConfigParser()
@@ -471,13 +494,23 @@ class INI():
             self.config = configparser.SafeConfigParser()
 
     def add_section(self, section):
+        """Add section.
+
+        Parameters
+        ----------
+        section : string
+            Section to add.
+        """
         self.config.read(self.filepath)
         self.config.add_section(section)
         with open(self.filepath, 'w') as f:
             self.config.write(f)
 
     def clear(self):
-        """ Remove all contents from file. Use with extreme caution.  """
+        """Remove all contents from file. Use with extreme caution.
+
+        .. warning:: This is a destructive action.
+        """
         with open(self.filepath, "w"):
             pass
         if sys.version[0] == '3':
@@ -487,21 +520,72 @@ class INI():
 
     @property
     def dictionary(self):
+        """Get a python dictionary of contents."""
         self.config.read(self.filepath)
         return self.config._sections
 
     def get_options(self, section):
+        """List the options in a section.
+
+        Parameters
+        ----------
+        section : string
+            The section to investigate.
+
+        Returns
+        -------
+        list of strings
+            The options within the given section.
+        """
         return list(self.dictionary[section].keys())
 
     def has_option(self, section, option):
+        """Test if file has option.
+
+        Parameters
+        ----------
+        section : string
+            Section.
+        option : string
+            Option.
+
+        Returns
+        -------
+        boolean
+        """
         self.config.read(self.filepath)
         return self.config.has_option(section, option)
 
     def has_section(self, section):
+        """Test if file has section.
+
+        Parameters
+        ----------
+        section : string
+            Section.
+
+        Returns
+        -------
+        boolean
+        """
         self.config.read(self.filepath)
         return self.config.has_section(section)
 
     def read(self, section, option):
+        """Read from file.
+
+        Parameters
+        ----------
+        section : string
+            Section.
+        option : string
+            Option.
+
+        Returns
+        -------
+        string
+            Value.
+        """
         self.config.read(self.filepath)
         raw = self.config.get(section, option)
         out = string2item(raw, sep=', ')
@@ -509,10 +593,22 @@ class INI():
 
     @property
     def sections(self):
+        """List of sections."""
         self.config.read(self.filepath)
         return self.config.sections()
 
     def write(self, section, option, value):
+        """Write to file.
+
+        Parameters
+        ----------
+        section : string
+            Section.
+        option : string
+            Option.
+        value : string
+            Value.
+        """
         self.config.read(self.filepath)
         string = item2string(value, sep=', ')
         self.config.set(section, option, string)
@@ -520,57 +616,8 @@ class INI():
             self.config.write(f)
 
 
-def plot_dats(folder=None, transpose=True):
-    """ Convinience function to plot raw data from COLORS """
-
-    import data
-    import artists
-
-    if folder:
-        pass
-    else:
-        folder = os.getcwd()
-
-    files = glob_handler('.dat', folder=folder)
-
-    for _file in files:
-
-        print(' ')
-
-        try:
-
-            dat_data = data.from_COLORS(_file)
-
-            fname = filename_parse(_file)[1]
-
-            dat_data.convert('wn')
-
-            # 1D
-            if len(dat_data.axes) == 1:
-                artist = artists.mpl_1D(dat_data, dat_data.axes[0].name)
-                artist.plot(0, autosave=True, output_folder=folder, fname=fname)
-
-            # 2D
-            elif len(dat_data.axes) == 2:
-                if transpose:
-                    dat_data.transpose()
-                artist = artists.mpl_2D(dat_data, dat_data.axes[0].name, dat_data.axes[1].name)
-                artist.plot(0, pixelated=True, contours=0, xbin=True, ybin=True,
-                            autosave=True, output_folder=folder, fname=fname)
-
-            else:
-                print('error! - dimensionality of data ({}) not recognized'.format(len(dat_data.axes)))
-
-        except BaseException:
-            import sys
-            print('dat {} not recognized as plottible in plot_dats'.format(
-                filename_parse(_file)[1]))
-            print(sys.exc_info()[0])
-            pass
-
-
 def read_data_column(path, name):
-    """ Read a named column of a PyCMDS data file as a single array.
+    """Read a named column of a PyCMDS data file as a single array.
 
     Parameters
     ----------
@@ -591,7 +638,7 @@ def read_data_column(path, name):
 
 
 def read_h5(filepath):
-    """ Read from a `HDF5 <https://www.hdfgroup.org/HDF5/doc/H5.intro.html>`_ file, returning the data within as a python dictionary.
+    """Read from a `HDF5`_ file, returning the data within as a python dictionary.
 
     Returns
     -------
@@ -611,7 +658,7 @@ def read_h5(filepath):
 
 
 def read_headers(filepath):
-    """ Read 'Wright group formatted' headers from given path.
+    """Read 'WrightTools formatted' headers from given path.
 
     Parameters
     ----------
@@ -622,6 +669,10 @@ def read_headers(filepath):
     -------
     OrderedDict
         Dictionary containing header information.
+
+    See Also
+    --------
+    kit.write_headers
     """
     headers = collections.OrderedDict()
     for line in open(filepath):
@@ -635,8 +686,7 @@ def read_headers(filepath):
 
 
 def write_h5(filepath, dictionary):
-    """ Save a python dictionary into an `HDF5 <https://www.hdfgroup.org/HDF5/doc/H5.intro.html>`_
-    file.
+    """Save a python dictionary into an `HDF5`_ file.
 
     Right now it only works to store numpy arrays of numbers.
 
@@ -653,7 +703,6 @@ def write_h5(filepath, dictionary):
     str
         The full filepath to the created HDF5 file.
 
-
     See Also
     --------
     kit.read_h5
@@ -681,7 +730,7 @@ def write_h5(filepath, dictionary):
 
 
 def write_headers(filepath, dictionary):
-    """ Write 'Wright Group formatted' headers to given file.
+    """Write 'WrightTooTools formatted' headers to given file.
 
     Headers written can be read again using read_headers.
 
@@ -696,6 +745,10 @@ def write_headers(filepath, dictionary):
     -------
     str
         Filepath of file.
+
+    See Also
+    --------
+    kit.read_headers
     """
     dictionary = copy.deepcopy(dictionary)
     # write header
@@ -718,7 +771,7 @@ def write_headers(filepath, dictionary):
 
 
 def closest_pair(arr, give='indicies'):
-    """ Find the pair of indices corresponding to the closest elements in an array.
+    """Find the pair of indices corresponding to the closest elements in an array.
 
     If multiple pairs are equally close, both pairs of indicies are returned.
     Optionally returns the closest distance itself.
@@ -770,7 +823,7 @@ def closest_pair(arr, give='indicies'):
 
 
 def diff(xi, yi, order=1):
-    """ Take the numerical derivative of a 1D array.
+    """Take the numerical derivative of a 1D array.
 
     Output is mapped onto the original coordinates  using linear interpolation.
 
@@ -802,7 +855,7 @@ def diff(xi, yi, order=1):
 
 
 def fft(xi, yi, axis=0):
-    """ Take the 1D FFT of an N-dimensional array and return "sensible" arrays which are shifted properly.
+    """Take the 1D FFT of an N-dimensional array and return "sensible" properly shifted arrays.
 
     Parameters
     ----------
@@ -820,7 +873,6 @@ def fft(xi, yi, axis=0):
         Example: if input xi is in the time domain, output xi is in frequency domain.
     yi : ND numpy.ndarray
         FFT. Has the same shape as the input array (yi).
-
     """
     yi = np.fft.fft(yi, axis=axis)
     d = (xi.max() - xi.min()) / (xi.size - 1)
@@ -832,8 +884,25 @@ def fft(xi, yi, axis=0):
 
 
 def mono_resolution(grooves_per_mm, slit_width, focal_length, output_color, output_units='wn'):
-    """
-    slit width mm, focal_length mm, output_color nm
+    """Calculate the resolution of a monochromator.
+
+    Parameters
+    ----------
+    grooves_per_mm : number
+        Grooves per millimeter.
+    slit_width : number
+        Slit width in microns.
+    focal_length : number
+        Focal length in mm.
+    output_color : number
+        Output color in nm.
+    output_units : string (optional)
+        Output units. Default is wn.
+
+    Returns
+    -------
+    float
+        Resolution.
     """
     d_lambda = 1e6 * slit_width / (grooves_per_mm * focal_length)  # nm
     upper = output_color + d_lambda / 2  # nm
@@ -843,7 +912,7 @@ def mono_resolution(grooves_per_mm, slit_width, focal_length, output_color, outp
 
 
 def nm_width(center, width, units='wn'):
-    """ Given a center and width, in energy units, get back a width in nm.
+    """Given a center and width, in energy units, get back a width in nm.
 
     Parameters
     ----------
@@ -865,9 +934,10 @@ def nm_width(center, width, units='wn'):
 
 
 def remove_nans_1D(arrs):
-    """ Remove nans in a list of 1D arrays.
+    """Remove nans in a list of 1D arrays.
 
-    Removes indicies in all arrays if any array is nan at that index. All input arrays must have the same size.
+    Removes indicies in all arrays if any array is nan at that index.
+    All input arrays must have the same size.
 
     Parameters
     ----------
@@ -894,7 +964,7 @@ def remove_nans_1D(arrs):
 
 def share_nans(arrs1):
     # Written by DJM. darienmorrow@gmail.com. January 15, 2016.
-    """ Takes a list of nD arrays and returns a new list of nD arrays.
+    """Take a list of nD arrays and return a new list of nD arrays.
 
     The new list is in the same order as the old list.
     If one indexed element in an old array is nan then every element for that
@@ -910,7 +980,6 @@ def share_nans(arrs1):
     list
         List of nD arrays in same order as given, with nan indicies syncronized.
     """
-
     nans = np.zeros((arrs1[0].shape))
 
     for arr in arrs1:
@@ -922,9 +991,12 @@ def share_nans(arrs1):
 
 
 def smooth_1D(arr, n=10):
-    """
-    smooth 1D data by 'running average'n
-    int n smoothing factor (num points)
+    """Smooth 1D data by 'running average'.
+
+    Parameters
+    ----------
+    n : int
+        number of points to average
     """
     for i in range(n, len(arr) - n):
         window = arr[i - n:i + n].copy()
@@ -933,13 +1005,14 @@ def smooth_1D(arr, n=10):
 
 
 class Spline:
+    """Spline."""
 
     def __call__(self, *args, **kwargs):
+        """Evaluate."""
         return self.true_spline(*args, **kwargs)
 
     def __init__(self, xi, yi, k=3, s=1000, ignore_nans=True):
-        """ Wrapper class for scipy.UnivariateSpline, made to be slightly less
-        finicky with things like decending xi arrays and nans.
+        """Initialize.
 
         Parameters
         ----------
@@ -955,7 +1028,7 @@ class Spline:
             Number of knots will be increased until the smoothing condition is
             satisfied::
 
-                sum((w[i] * (y[i]-spl(x[i])))**2, axis=0) <= s
+            ``sum((w[i] * (y[i]-spl(x[i])))**2, axis=0) <= s``
 
             If 0, spline will interpolate through all data points. Default is
             1000.
@@ -983,7 +1056,7 @@ class Spline:
 
 
 def unique(arr, tolerance=1e-6):
-    """ Return unique elements in 1D array, within tolerance.
+    """Return unique elements in 1D array, within tolerance.
 
     Parameters
     ----------
@@ -1010,7 +1083,7 @@ def unique(arr, tolerance=1e-6):
 
 def zoom2D(xi, yi, zi, xi_zoom=3., yi_zoom=3., order=3, mode='nearest',
            cval=0.):
-    """ Zoom a 2D array, with axes.
+    """Zoom a 2D array, with axes.
 
     Parameters
     ----------
@@ -1041,7 +1114,7 @@ def zoom2D(xi, yi, zi, xi_zoom=3., yi_zoom=3., order=3, mode='nearest',
 
 
 def array2string(array, sep='\t'):
-    """ Generate a string from an array with useful formatting.
+    """Generate a string from an array with useful formatting.
 
     Great for writing arrays into single lines in files.
 
@@ -1057,12 +1130,16 @@ def array2string(array, sep='\t'):
 
 
 def flatten_list(l):
-    """ Flatten an irregular list.
+    """Flatten an irregular list.
 
     Works generally but may be slower than it could
     be if you can make assumptions about your list.
 
-    Adapted from http://stackoverflow.com/questions/2158395
+
+    `Source`__
+
+    __ flatten_
+
 
         >>> l = [[[1, 2, 3], [4, 5]], 6]
         >>> wt.kit.flatten_list(l)
@@ -1086,7 +1163,7 @@ def flatten_list(l):
 
 def get_methods(the_class, class_only=False, instance_only=False,
                 exclude_internal=True):
-    """ get a list of strings corresponding to the names of the methods of an object.  """
+    """Get a list of strings corresponding to the names of the methods of an object."""
     import inspect
 
     def acceptMethod(tup):
@@ -1095,7 +1172,8 @@ def get_methods(the_class, class_only=False, instance_only=False,
         is_method = inspect.ismethod(tup[1])
         if is_method:
             bound_to = tup[1].im_self
-            internal = tup[1].im_func.func_name[:2] == '__' and tup[1].im_func.func_name[-2:] == '__'
+            internal = (tup[1].im_func.func_name[:2] == '__' and
+                        tup[1].im_func.func_name[-2:] == '__')
             if internal and exclude_internal:
                 include = False
             else:
@@ -1111,9 +1189,11 @@ def get_methods(the_class, class_only=False, instance_only=False,
 
 
 def intersperse(lst, item):
-    """ Put item between each existing item in list.
+    """Put item between each existing item in list.
 
-    From http://stackoverflow.com/a/5921708
+    `Source`__
+
+    __ intersperse_
     """
     result = [item] * (len(lst) * 2 - 1)
     result[0::2] = lst
@@ -1121,7 +1201,23 @@ def intersperse(lst, item):
 
 
 def item2string(item, sep='\t'):
-    # TODO: document
+    r"""Generate string from item.
+
+    Parameters
+    ----------
+    item : object
+        Item.
+    sep : string (optional)
+        Separator. Default is '\t'.
+
+    Returns
+    -------
+    string
+
+    See Also
+    --------
+    string2item
+    """
     out = ''
     if isinstance(item, string_type):
         out += '\'' + item + '\''
@@ -1146,7 +1242,7 @@ identity_operators = ['=', '+', '-', '*', '/', 'F']
 
 
 def parse_identity(string):
-    """ Parse an identity string into its components.
+    """Parse an identity string into its components.
 
     Returns
     -------
@@ -1159,7 +1255,7 @@ def parse_identity(string):
 
 
 class suppress_stdout_stderr(object):
-    """ A context manager for doing a "deep suppression" of stdout and stderr in Python
+    """Context manager for doing a "deep suppression" of stdout and stderr in Python.
 
     i.e. will suppress all print, even if the print originates in a
     compiled C/Fortran sub-function.
@@ -1168,24 +1264,31 @@ class suppress_stdout_stderr(object):
     to stderr just before a script exits, and after the context manager has
     exited (at least, I think that is why it lets exceptions through).
 
-    from http://stackoverflow.com/questions/11130156/suppress-stdout-stderr-print-from-python-functions
+    `Source`__
+
+    __ suppress_
+
+
+    >>> with wt.kit.suppress_stdout_stderr():
+    ...     rogue_function()
 
-    with wt.kit.suppress_stdout_stderr():
-        rogue_function()
     """
 
     def __init__(self):
+        """init."""
         # Open a pair of null files
         self.null_fds = [os.open(os.devnull, os.O_RDWR) for x in range(2)]
         # Save the actual stdout (1) and stderr (2) file descriptors.
         self.save_fds = (os.dup(1), os.dup(2))
 
     def __enter__(self):
+        """enter."""
         # Assign the null pointers to stdout and stderr.
         os.dup2(self.null_fds[0], 1)
         os.dup2(self.null_fds[1], 2)
 
     def __exit__(self, *_):
+        """exit."""
         # Re-assign the real stdout/stderr back to (1) and (2)
         os.dup2(self.save_fds[0], 1)
         os.dup2(self.save_fds[1], 2)
@@ -1195,7 +1298,7 @@ class suppress_stdout_stderr(object):
 
 
 def string2array(string, sep='\t'):
-    """ Generate an array from a string created using array2string.
+    """Generate an array from a string created using array2string.
 
     See Also
     --------
@@ -1239,8 +1342,50 @@ def string2array(string, sep='\t'):
     return arr
 
 
+def string2identifier(s):
+    """Turn a string into a valid python identifier.
+
+    Parameters
+    ----------
+    s : string
+        string to convert
+
+    Returns
+    -------
+    str
+        valid python identifier.
+    """
+    # https://docs.python.org/3/reference/lexical_analysis.html#identifiers
+    if s[0] not in string.ascii_letters:
+        s = '_' + s
+    valids = string.ascii_letters + string.digits + '_'
+    out = ''
+    for i, char in enumerate(s):
+        if char in valids:
+            out += char
+        else:
+            out += '_'
+    return out
+
+
 def string2item(string, sep='\t'):
-    # TODO: document
+    r"""Turn a string into a python object.
+
+    Parameters
+    ----------
+    string : string
+        String.
+    sep : string (optional)
+        Seperator. Default is '\t'.
+
+    Returns
+    -------
+    object
+
+    See Also
+    --------
+    item2string
+    """
     if string[0] == '\'' and string[-1] == '\'':
         out = string[1:-1]
     else:
@@ -1325,7 +1470,7 @@ unicode_dictionary['omega'] = u'\u03C9'
 
 
 def update_progress(progress, carriage_return=False, length=50):
-    """ prints a pretty progress bar to the console
+    """Print a pretty progress bar to the console.
 
     accepts 'progress' as a percentage
     bool carriage_return toggles overwrite behavior
@@ -1345,15 +1490,22 @@ def update_progress(progress, carriage_return=False, length=50):
 
 
 class Timer:
-    """ with Timer(): your_code() """
+    """Context manager for timing code.
+
+    >>> with Timer():
+    ...     your_code()
+    """
 
     def __init__(self, verbose=True):
+        """init."""
         self.verbose = verbose
 
     def __enter__(self, progress=None):
+        """enter."""
         self.start = clock()
 
     def __exit__(self, type, value, traceback):
+        """exit."""
         self.end = clock()
         self.interval = self.end - self.start
         if self.verbose:
