@@ -1,6 +1,4 @@
-"""
-OPA tuning curves.
-"""
+"""OPA tuning curves."""
 
 
 # --- import --------------------------------------------------------------------------------------
@@ -17,17 +15,12 @@ import numpy as np
 
 import scipy
 
-import matplotlib
-from mpl_toolkits.axes_grid1 import host_subplot
-import mpl_toolkits.axisartist as AA
 import matplotlib.pyplot as plt
 import matplotlib.gridspec as grd
 
 from .. import units as wt_units
 from .. import kit as wt_kit
 
-debug = False
-
 
 # --- define --------------------------------------------------------------------------------------
 
@@ -70,9 +63,20 @@ TOPAS_interaction_by_kind = {'TOPAS-C': TOPAS_C_interactions,
 
 
 class Linear:
+    """Linear interpolation."""
 
     def __init__(self, colors, units, motors):
-        """ Linear interpolation using scipy.interpolate.InterpolatedUnivariateSpline.  """
+        """Create a ``Linear`` object.
+
+        Parameters
+        ----------
+        colors : 1D array
+            Setpoints.
+        units : string
+            Units.
+        motors : list of WrightTools.tuning.curve.Motor
+            Motors.
+        """
         self.colors = colors
         self.units = units
         self.motors = motors
@@ -80,22 +84,36 @@ class Linear:
         self.i_functions = [wt_kit.Spline(motor.positions, colors, k=1, s=0) for motor in motors]
 
     def get_motor_positions(self, color):
-        return [f(color) for f in self.functions]
+        """Get motor positions.
 
-    def get_color(self, motor_index, motor_position):
-        motor = self.motors[motor_index]
-        if motor.positions.min() < motor_position < motor.positions.max():
-            pass
-        else:
-            # take closest valid motor position if outside of range
-            idx = (np.abs(motor.positions - motor_position)).argmin()
-            motor_position = motor.positions[idx]
-        return self.i_functions[motor_index](motor_position)
+        Parameters
+        ----------
+        color : number
+            Destination, in units.
+
+        Returns
+        -------
+        list of numbers
+            Motor positions.
+        """
+        return [f(color) for f in self.functions]
 
 
 class Poly:
+    """Polynomial interpolation."""
 
     def __init__(self, colors, units, motors):
+        """Create a ``Poly`` object.
+
+        Parameters
+        ----------
+        colors : 1D array
+            Setpoints.
+        units : string
+            Units.
+        motors : list of WrightTools.tuning.curve.Motor
+            Motors.
+        """
         self.colors = colors
         self.n = 8
         self.fit_params = []
@@ -105,26 +123,40 @@ class Poly:
         self.linear = Linear(colors, units, motors)
 
     def get_motor_positions(self, color):
+        """Get motor positions.
+
+        Parameters
+        ----------
+        color : number
+            Destination, in units.
+
+        Returns
+        -------
+        list of numbers
+            Motor positions.
+        """
         outs = []
         for params in self.fit_params:
             out = np.polynomial.polynomial.polyval(color, params[0])
             outs.append(out)
         return outs
 
-    def get_color(self, motor_index, motor_position):
-        a = self.fit_params[motor_index][0][::-1].copy()
-        a[-1] -= motor_position
-        roots = np.real(np.roots(a))
-        # return root closest to guess from linear interpolation
-        guess = self.linear.get_color(motor_index, motor_position)
-        idx = (np.abs(roots - guess)).argmin()
-        return roots[idx]
-
 
 class Spline:
+    """Spline interpolation."""
 
     def __init__(self, colors, units, motors):
-        """ Linear interpolation using scipy.interpolate.InterpolatedUnivariateSpline.  """
+        """Create a ``Spline`` object.
+
+        Parameters
+        ----------
+        colors : 1D array
+            Setpoints.
+        units : string
+            Units.
+        motors : list of WrightTools.tuning.curve.Motor
+            Motors.
+        """
         self.colors = colors
         self.units = units
         self.motors = motors
@@ -134,36 +166,48 @@ class Spline:
             motor.positions, colors, k=3, s=1000) for motor in motors]
 
     def get_motor_positions(self, color):
-        return [f(color) for f in self.functions]
+        """Get motor positions.
 
-    def get_color(self, motor_index, motor_position):
-        motor = self.motors[motor_index]
-        if motor.positions.min() < motor_position < motor.positions.max():
-            pass
-        else:
-            # take closest valid motor position if outside of range
-            idx = (np.abs(motor.positions - motor_position)).argmin()
-            motor_position = motor.positions[idx]
-        return self.i_functions[motor_index](motor_position)
+        Parameters
+        ----------
+        color : number
+            Destination, in units.
+
+        Returns
+        -------
+        list of numbers
+            Motor positions.
+        """
+        return [f(color) for f in self.functions]
 
 
 # --- curve class ---------------------------------------------------------------------------------
 
 
 class Motor:
+    """Container class for motor arrays."""
 
     def __init__(self, positions, name):
-        """ Container class for motor arrays.  """
+        """Create a ``Motor`` object.
+
+        Parameters
+        ----------
+        positions : 1D array
+            Motor positions.
+        name : string
+            Name.
+        """
         self.positions = positions
         self.name = name
 
 
 class Curve:
+    """Central object-type for all OPA tuning curves."""
 
     def __init__(self, colors, units, motors, name, interaction,
                  kind, method=Linear,
                  subcurve=None, source_colors=None):
-        """ Central object-type for all OPA tuning curves.
+        """Create a ``Curve`` object.
 
         Parameters
         ----------
@@ -175,7 +219,7 @@ class Curve:
             Motor positions for each color.
         name : str
             Name of curve.
-        kind : {'opa800'}
+        kind : string
             The kind of curve (for saving).
         method : interpolation class
             The interpolation method to use.
@@ -212,14 +256,14 @@ class Curve:
         return '\n'.join(outs)
 
     def coerce_motors(self):
-        """ Coerce the motor positions to lie exactly along the interpolation positions.
+        """Coerce the motor positions to lie exactly along the interpolation positions.
 
         Can be thought of as 'smoothing' the curve.
         """
         self.map_colors(self.colors, units='same')
 
     def convert(self, units):
-        """ Convert the colors.
+        """Convert the colors to new units.
 
         Parameters
         ----------
@@ -234,7 +278,7 @@ class Curve:
         self.interpolate()  # how did it ever work if this wasn't here?  - Blaise 2017-03-22
 
     def copy(self):
-        """ Copy the object.
+        """Copy the curve object.
 
         Returns
         -------
@@ -244,7 +288,7 @@ class Curve:
         return copy.deepcopy(self)
 
     def get_color(self, motor_positions, units='same'):
-        """ Get the color given a set of motor positions.
+        """Get the color given a set of motor positions.
 
         Parameters
         ----------
@@ -266,7 +310,7 @@ class Curve:
         return colors[0]
 
     def get_limits(self, units='same'):
-        """ Get the edges of the curve.
+        """Get the edges of the curve.
 
         Parameters
         ----------
@@ -285,6 +329,18 @@ class Curve:
             return [units_colors.min(), units_colors.max()]
 
     def get_motor_names(self, full=True):
+        """Get motor names.
+
+        Parameters
+        ----------
+        full : boolean (optional)
+            Toggle inclusion of motor names from subcurve.
+
+        Returns
+        -------
+        list of strings
+            Motor names.
+        """
         if self.subcurve and full:
             subcurve_motor_names = self.subcurve.get_motor_names()
         else:
@@ -292,7 +348,7 @@ class Curve:
         return subcurve_motor_names + [m.name for m in self.motors]
 
     def get_motor_positions(self, color, units='same', full=True):
-        """ Get the motor positions for a destination color.
+        """Get the motor positions for a destination color.
 
         Parameters
         ----------
@@ -335,6 +391,20 @@ class Curve:
             return out.T
 
     def get_source_color(self, color, units='same'):
+        """Get color of source curve.
+
+        Parameters
+        ----------
+        color : number or 1D array
+            Color(s).
+        units : string (optional)
+            Units. Default is same.
+
+        Returns
+        -------
+        number or 1D array
+            Source color(s).
+        """
         if not self.subcurve:
             return None
         # color must be array
@@ -342,6 +412,7 @@ class Curve:
         def is_numeric(obj):
             attrs = ['__add__', '__sub__', '__mul__', '__div__', '__pow__']
             return all([hasattr(obj, attr) for attr in attrs] + [not hasattr(obj, '__len__')])
+
         if is_numeric(color):
             color = np.array([color])
         # get color in units
@@ -353,14 +424,20 @@ class Curve:
         return np.array([self.source_color_interpolator.get_motor_positions(c) for c in color])
 
     def interpolate(self, interpolate_subcurve=True):
-        """ Generate the interploator object.  """
+        """Generate the interploator object.
+
+        Parameters
+        ----------
+        interpolate_subcurve : boolean (optional)
+            Toggle interpolation of subcurve. Default is True.
+        """
         self.interpolator = self.method(self.colors, self.units, self.motors)
         if self.subcurve and interpolate_subcurve:
             self.source_color_interpolator = self.method(
                 self.colors, self.units, [self.source_colors])
 
     def map_colors(self, colors, units='same'):
-        """ Map the curve onto new tune points using the curve's own interpolation method
+        """Map the curve onto new tune points using the curve's own interpolation method.
 
         Parameters
         ----------
@@ -404,7 +481,7 @@ class Curve:
         self.interpolate(interpolate_subcurve=True)
 
     def offset_by(self, motor, amount):
-        """ Offset a motor by some ammount.
+        """Offset a motor by some ammount.
 
         Parameters
         ----------
@@ -429,7 +506,7 @@ class Curve:
         self.interpolate()
 
     def offset_to(self, motor, destination, color, color_units='same'):
-        """ Offset a motor such that it evaluates to `destination` at `color`.
+        """Offset a motor such that it evaluates to `destination` at `color`.
 
         Parameters
         ----------
@@ -460,7 +537,7 @@ class Curve:
         self.offset_by(motor, offset)
 
     def plot(self, autosave=False, save_path='', title=None):
-        """ Plot the curve.  """
+        """Plot the curve."""
         # count number of subcurves
         subcurve_count = 0
         total_motor_count = len(self.motors)
@@ -545,7 +622,7 @@ class Curve:
             plt.close(fig)
 
     def save(self, save_directory=None, plot=True, verbose=True, full=False):
-        """ Save the curve.
+        """Save the curve.
 
         Parameters
         ----------
@@ -594,6 +671,17 @@ class Curve:
 
 
 def from_800_curve(filepath):
+    """Generate a Curve object from a file.
+
+    Parameters
+    ----------
+    filepath : string
+        Filepath.
+
+    Returns
+    -------
+    WrightTools.tuning.curve.Curve
+    """
     headers = wt_kit.read_headers(filepath)
     arr = np.genfromtxt(filepath).T
     colors = arr[0]
@@ -609,7 +697,19 @@ def from_800_curve(filepath):
 
 
 def from_poynting_curve(filepath, subcurve=None):
-    print('FROM POYNTING CURVE', filepath, subcurve)
+    """Generate a Curve object from a file.
+
+    Parameters
+    ----------
+    filepath : string
+        Filepath.
+    subcurve : WrightTools.curve.Curve
+        Subcurve.
+
+    Returns
+    -------
+    WrightTools.tuning.curve.Curve
+    """
     # read from file
     headers = wt_kit.read_headers(filepath)
     arr = np.genfromtxt(filepath).T
@@ -635,7 +735,7 @@ def from_poynting_curve(filepath, subcurve=None):
 
 
 def from_TOPAS_crvs(filepaths, kind, interaction_string):
-    """ Create a curve object from a TOPAS crv file
+    """Create a curve object from a TOPAS crv file.
 
     Parameters
     ----------
@@ -649,7 +749,7 @@ def from_TOPAS_crvs(filepaths, kind, interaction_string):
         e.g. 'NON-SF-NON-Sig'.
 
     Returns
-    ------
+    -------
     WrightTools.tuning.curve.Curve object
     """
     TOPAS_interactions = TOPAS_interaction_by_kind[kind]
@@ -703,6 +803,20 @@ def from_TOPAS_crvs(filepaths, kind, interaction_string):
 
 
 def to_800_curve(curve, save_directory):
+    """Save a curve object.
+
+    Parameters
+    ----------
+    curve : WrightTools.tuning.curve.Curve object
+        Curve.
+    save_directory : string.
+        Save directory.
+
+    Returns
+    -------
+    string
+        Output path.
+    """
     # ensure curve is in wn
     curve = curve.copy()
     curve.convert('wn')
@@ -729,6 +843,20 @@ def to_800_curve(curve, save_directory):
 
 
 def to_poynting_curve(curve, save_directory):
+    """Save a curve object.
+
+    Parameters
+    ----------
+    curve : WrightTools.tuning.curve.Curve object
+        Curve.
+    save_directory : string.
+        Save directory.
+
+    Returns
+    -------
+    string
+        Output path.
+    """
     # ensure curve is in wn
     curve = curve.copy()
     curve.convert('wn')
@@ -758,6 +886,25 @@ def to_poynting_curve(curve, save_directory):
 
 
 def to_TOPAS_crvs(curve, save_directory, kind, full, **kwargs):
+    """Save a curve object.
+
+    Parameters
+    ----------
+    curve : WrightTools.tuning.curve.Curve object
+        Curve.
+    save_directory : string.
+        Save directory.
+    kind : string
+        Curve kind.
+    full : boolean
+        Toggle saving subcurves.
+    **kwargs
+
+    Returns
+    -------
+    string
+        Output path.
+    """
     TOPAS_interactions = TOPAS_interaction_by_kind[kind]
     # unpack
     curve = curve.copy()
