@@ -1,6 +1,4 @@
-"""
-Tools for processing spectral delay correction data.
-"""
+"""Tools for processing spectral delay correction data."""
 
 
 # --- import --------------------------------------------------------------------------------------
@@ -9,37 +7,17 @@ Tools for processing spectral delay correction data.
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 import os
-import re
-import sys
-import imp
-import time
-import copy
-import inspect
-import itertools
-import subprocess
-import glob
 
-try:
-    import configparser as _ConfigParser  # python 3
-except ImportError:
-    import ConfigParser as _ConfigParser  # python 2
-
-import matplotlib
 import matplotlib.pyplot as plt
-import matplotlib.gridspec as grd
 
 import numpy as np
 
-import scipy
-from scipy.optimize import leastsq
-from scipy.interpolate import griddata, interp1d, interp2d, UnivariateSpline
+from scipy.interpolate import UnivariateSpline
 
 from .. import artists as wt_artists
-from .. import units as wt_units
 from .. import kit as wt_kit
 from .. import fit as wt_fit
 from .. import data as wt_data
-from . import curve as wt_curve
 from . import coset as wt_coset
 
 
@@ -49,7 +27,7 @@ from . import coset as wt_coset
 def process_wigner(data_filepath, channel, control_name,
                    offset_name, coset_name, color_units='nm',
                    delay_units='fs', autosave=True, s=1000):
-    """ Create a coset file from a measured wigner.
+    """Create a coset file from a measured wigner.
 
     Parameters
     ----------
@@ -118,7 +96,8 @@ def process_wigner(data_filepath, channel, control_name,
 def process_brute_force(data_filepath, opa_index, channel, color_units='nm',
                         delay_units='fs', amplitude_cutoff_factor=0.5,
                         plot=True, autosave=True):
-    """
+    """Brute force process Spectral Delay Correction.
+
     This method is a good idea, but it isn't ready for prime time yet.
     - Blaise 2016.03.18
     """
@@ -134,6 +113,7 @@ def process_brute_force(data_filepath, opa_index, channel, color_units='nm',
     else:
         print('channel type not recognized')
         return
+
     # pre-process data
     data.normalize(channel_index)
     data.convert(color_units, verbose=False)
@@ -154,6 +134,7 @@ def process_brute_force(data_filepath, opa_index, channel, color_units='nm',
         xi = d.axes[0].points
         yi = d.channels[channel_index].values
         return function.fit(yi, xi)
+
     x_outs = [fitit(d) for d in x_bins]
     y_outs = [fitit(d) for d in y_bins]
     x_centers = [o[0] for o in x_outs]
@@ -165,16 +146,12 @@ def process_brute_force(data_filepath, opa_index, channel, color_units='nm',
         centers[centers < lower_cutoff] = np.nan
         centers[centers > upper_cutoff] = np.nan
         amplitudes = np.array([o[2] for o in outs])
-        if False:
-            # HACK - Blaise
-            print(ws)
-            amplitudes[:-20] = np.nan
-            #plt.plot(ws, amplitudes)
         amplitudes[amplitudes < amplitudes.max() * amplitude_cutoff_factor] = np.nan
         ws_internal, centers, amplitudes = wt_kit.remove_nans_1D(
             [ws_internal, centers, amplitudes])
         spline = UnivariateSpline(ws_internal, centers, k=2, s=10000)
         return spline(ws)
+
     x_corrections = get_corrections(
         ws, x_outs, datas[0].axes[1].points.min(), datas[0].axes[1].points.max())
     y_corrections = get_corrections(
